# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Report(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "currency": "str",
        "download_url": "str",
        "file_id": "str",
        "file_name": "str",
        "hash_sum": "str",
        "report_type": "str",
        "settlement_date": "str",
        "settlement_id": "int",
        "size": "int",
        "status": "str",
        "website_name": "str",
    }

    attribute_map = {
        "currency": "currency",
        "download_url": "downloadUrl",
        "file_id": "fileId",
        "file_name": "fileName",
        "hash_sum": "hashSum",
        "report_type": "reportType",
        "settlement_date": "settlementDate",
        "settlement_id": "settlementId",
        "size": "size",
        "status": "status",
        "website_name": "websiteName",
    }

    def __init__(
        self,
        currency=None,
        download_url=None,
        file_id=None,
        file_name=None,
        hash_sum=None,
        report_type=None,
        settlement_date=None,
        settlement_id=None,
        size=None,
        status=None,
        website_name=None,
    ):  # noqa: E501
        """Report - a model defined in Swagger"""  # noqa: E501

        self._currency = None
        self._download_url = None
        self._file_id = None
        self._file_name = None
        self._hash_sum = None
        self._report_type = None
        self._settlement_date = None
        self._settlement_id = None
        self._size = None
        self._status = None
        self._website_name = None
        self.discriminator = None

        if currency is not None:
            self.currency = currency
        if download_url is not None:
            self.download_url = download_url
        if file_id is not None:
            self.file_id = file_id
        if file_name is not None:
            self.file_name = file_name
        if hash_sum is not None:
            self.hash_sum = hash_sum
        if report_type is not None:
            self.report_type = report_type
        if settlement_date is not None:
            self.settlement_date = settlement_date
        if settlement_id is not None:
            self.settlement_id = settlement_id
        if size is not None:
            self.size = size
        if status is not None:
            self.status = status
        if website_name is not None:
            self.website_name = website_name

    @property
    def currency(self):
        """Gets the currency of this Report.  # noqa: E501


        :return: The currency of this Report.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Report.


        :param currency: The currency of this Report.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def download_url(self):
        """Gets the download_url of this Report.  # noqa: E501


        :return: The download_url of this Report.  # noqa: E501
        :rtype: str
        """
        return self._download_url

    @download_url.setter
    def download_url(self, download_url):
        """Sets the download_url of this Report.


        :param download_url: The download_url of this Report.  # noqa: E501
        :type: str
        """

        self._download_url = download_url

    @property
    def file_id(self):
        """Gets the file_id of this Report.  # noqa: E501


        :return: The file_id of this Report.  # noqa: E501
        :rtype: str
        """
        return self._file_id

    @file_id.setter
    def file_id(self, file_id):
        """Sets the file_id of this Report.


        :param file_id: The file_id of this Report.  # noqa: E501
        :type: str
        """

        self._file_id = file_id

    @property
    def file_name(self):
        """Gets the file_name of this Report.  # noqa: E501


        :return: The file_name of this Report.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this Report.


        :param file_name: The file_name of this Report.  # noqa: E501
        :type: str
        """

        self._file_name = file_name

    @property
    def hash_sum(self):
        """Gets the hash_sum of this Report.  # noqa: E501


        :return: The hash_sum of this Report.  # noqa: E501
        :rtype: str
        """
        return self._hash_sum

    @hash_sum.setter
    def hash_sum(self, hash_sum):
        """Sets the hash_sum of this Report.


        :param hash_sum: The hash_sum of this Report.  # noqa: E501
        :type: str
        """

        self._hash_sum = hash_sum

    @property
    def report_type(self):
        """Gets the report_type of this Report.  # noqa: E501


        :return: The report_type of this Report.  # noqa: E501
        :rtype: str
        """
        return self._report_type

    @report_type.setter
    def report_type(self, report_type):
        """Sets the report_type of this Report.


        :param report_type: The report_type of this Report.  # noqa: E501
        :type: str
        """

        self._report_type = report_type

    @property
    def settlement_date(self):
        """Gets the settlement_date of this Report.  # noqa: E501


        :return: The settlement_date of this Report.  # noqa: E501
        :rtype: str
        """
        return self._settlement_date

    @settlement_date.setter
    def settlement_date(self, settlement_date):
        """Sets the settlement_date of this Report.


        :param settlement_date: The settlement_date of this Report.  # noqa: E501
        :type: str
        """

        self._settlement_date = settlement_date

    @property
    def settlement_id(self):
        """Gets the settlement_id of this Report.  # noqa: E501


        :return: The settlement_id of this Report.  # noqa: E501
        :rtype: int
        """
        return self._settlement_id

    @settlement_id.setter
    def settlement_id(self, settlement_id):
        """Sets the settlement_id of this Report.


        :param settlement_id: The settlement_id of this Report.  # noqa: E501
        :type: int
        """

        self._settlement_id = settlement_id

    @property
    def size(self):
        """Gets the size of this Report.  # noqa: E501


        :return: The size of this Report.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this Report.


        :param size: The size of this Report.  # noqa: E501
        :type: int
        """

        self._size = size

    class Status(object):
        IN_PROGRESS = "IN_PROGRESS"
        COMPLETED = "COMPLETED"
        FAILED = "FAILED"

    @property
    def status(self):
        """Gets the status of this Report.  # noqa: E501


        :return: The status of this Report.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Report.


        :param status: The status of this Report.  # noqa: E501
        :type: str
        """
        allowed_values = ["IN_PROGRESS", "COMPLETED", "FAILED"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                    status, allowed_values
                )
            )

        self._status = status

    @property
    def website_name(self):
        """Gets the website_name of this Report.  # noqa: E501


        :return: The website_name of this Report.  # noqa: E501
        :rtype: str
        """
        return self._website_name

    @website_name.setter
    def website_name(self, website_name):
        """Sets the website_name of this Report.


        :param website_name: The website_name of this Report.  # noqa: E501
        :type: str
        """

        self._website_name = website_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(Report, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Report):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ReportsData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "end_date": "date",
        "report_type": "list[str]",
        "start_date": "date",
    }

    attribute_map = {
        "end_date": "end_date",
        "report_type": "report_type",
        "start_date": "start_date",
    }

    def __init__(self, end_date=None, report_type=None, start_date=None):  # noqa: E501
        """ReportsData - a model defined in Swagger"""  # noqa: E501

        self._end_date = None
        self._report_type = None
        self._start_date = None
        self.discriminator = None

        if end_date is not None:
            self.end_date = end_date
        if report_type is not None:
            self.report_type = report_type
        self.start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this ReportsData.  # noqa: E501

        End date of period in which the reports were generated. Period between dates is no more than 7 days. Format: yyyy-MM-dd  # noqa: E501

        :return: The end_date of this ReportsData.  # noqa: E501
        :rtype: date
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this ReportsData.

        End date of period in which the reports were generated. Period between dates is no more than 7 days. Format: yyyy-MM-dd  # noqa: E501

        :param end_date: The end_date of this ReportsData.  # noqa: E501
        :type: date
        """

        self._end_date = end_date

    @property
    def report_type(self):
        """Gets the report_type of this ReportsData.  # noqa: E501

        Specific report type. Now are available: \"regular_settlement\", \"icpp_settlement\"  # noqa: E501

        :return: The report_type of this ReportsData.  # noqa: E501
        :rtype: list[str]
        """
        return self._report_type

    @report_type.setter
    def report_type(self, report_type):
        """Sets the report_type of this ReportsData.

        Specific report type. Now are available: \"regular_settlement\", \"icpp_settlement\"  # noqa: E501

        :param report_type: The report_type of this ReportsData.  # noqa: E501
        :type: list[str]
        """

        self._report_type = report_type

    @property
    def start_date(self):
        """Gets the start_date of this ReportsData.  # noqa: E501

        Start date of period in which the reports were generated. Format: yyyy-MM-dd  # noqa: E501

        :return: The start_date of this ReportsData.  # noqa: E501
        :rtype: date
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this ReportsData.

        Start date of period in which the reports were generated. Format: yyyy-MM-dd  # noqa: E501

        :param start_date: The start_date of this ReportsData.  # noqa: E501
        :type: date
        """
        if start_date is None:
            raise ValueError(
                "Invalid value for `start_date`, must not be `None`"
            )  # noqa: E501

        self._start_date = start_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(ReportsData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReportsData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class OAuthError(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"name": "str", "message": "str"}

    attribute_map = {"name": "name", "message": "message"}

    def __init__(self, name=None, message=None):  # noqa: E501
        """OAuthError - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._message = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if message is not None:
            self.message = message

    class Name(object):
        REQUEST = "INVALID_REQUEST"
        GRANT = "INVALID_GRANT"
        TOKEN = "INVALID_TOKEN"

    @property
    def name(self):
        """Gets the name of this OAuthError.  # noqa: E501

        Error code  # noqa: E501

        :return: The name of this OAuthError.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this OAuthError.

        Error code  # noqa: E501

        :param name: The name of this OAuthError.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "INVALID_REQUEST",
            "INVALID_GRANT",
            "INVALID_TOKEN",
        ]  # noqa: E501
        if name not in allowed_values:
            raise ValueError(
                "Invalid value for `name` ({0}), must be one of {1}".format(  # noqa: E501
                    name, allowed_values
                )
            )

        self._name = name

    @property
    def message(self):
        """Gets the message of this OAuthError.  # noqa: E501

        Error description  # noqa: E501

        :return: The message of this OAuthError.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this OAuthError.

        Error description  # noqa: E501

        :param message: The message of this OAuthError.  # noqa: E501
        :type: str
        """

        self._message = message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(OAuthError, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OAuthError):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DisputeResponsePaymentData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "amount": "str",
        "arn": "str",
        "auth_code": "str",
        "created": "str",
        "currency": "str",
        "id": "str",
    }

    attribute_map = {
        "amount": "amount",
        "arn": "arn",
        "auth_code": "auth_code",
        "created": "created",
        "currency": "currency",
        "id": "id",
    }

    def __init__(
        self,
        amount=None,
        arn=None,
        auth_code=None,
        created=None,
        currency=None,
        id=None,
    ):  # noqa: E501
        """DisputeResponsePaymentData - a model defined in Swagger"""  # noqa: E501

        self._amount = None
        self._arn = None
        self._auth_code = None
        self._created = None
        self._currency = None
        self._id = None
        self.discriminator = None

        if amount is not None:
            self.amount = amount
        if arn is not None:
            self.arn = arn
        if auth_code is not None:
            self.auth_code = auth_code
        if created is not None:
            self.created = created
        if currency is not None:
            self.currency = currency
        if id is not None:
            self.id = id

    @property
    def amount(self):
        """Gets the amount of this DisputeResponsePaymentData.  # noqa: E501

        Payment amount  # noqa: E501

        :return: The amount of this DisputeResponsePaymentData.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this DisputeResponsePaymentData.

        Payment amount  # noqa: E501

        :param amount: The amount of this DisputeResponsePaymentData.  # noqa: E501
        :type: str
        """

        self._amount = amount

    @property
    def arn(self):
        """Gets the arn of this DisputeResponsePaymentData.  # noqa: E501

        ARN (Acquirer Reference Number), supplied by the acquiring financial institution, return only after receiving ARN from bank acquirer  # noqa: E501

        :return: The arn of this DisputeResponsePaymentData.  # noqa: E501
        :rtype: str
        """
        return self._arn

    @arn.setter
    def arn(self, arn):
        """Sets the arn of this DisputeResponsePaymentData.

        ARN (Acquirer Reference Number), supplied by the acquiring financial institution, return only after receiving ARN from bank acquirer  # noqa: E501

        :param arn: The arn of this DisputeResponsePaymentData.  # noqa: E501
        :type: str
        """

        self._arn = arn

    @property
    def auth_code(self):
        """Gets the auth_code of this DisputeResponsePaymentData.  # noqa: E501

        Authorization code, provided by bank  # noqa: E501

        :return: The auth_code of this DisputeResponsePaymentData.  # noqa: E501
        :rtype: str
        """
        return self._auth_code

    @auth_code.setter
    def auth_code(self, auth_code):
        """Sets the auth_code of this DisputeResponsePaymentData.

        Authorization code, provided by bank  # noqa: E501

        :param auth_code: The auth_code of this DisputeResponsePaymentData.  # noqa: E501
        :type: str
        """

        self._auth_code = auth_code

    @property
    def created(self):
        """Gets the created of this DisputeResponsePaymentData.  # noqa: E501

        Payment creation date in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format (format - yyyy-MM-dd'T'HH:mm:ss'Z')  # noqa: E501

        :return: The created of this DisputeResponsePaymentData.  # noqa: E501
        :rtype: str
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this DisputeResponsePaymentData.

        Payment creation date in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format (format - yyyy-MM-dd'T'HH:mm:ss'Z')  # noqa: E501

        :param created: The created of this DisputeResponsePaymentData.  # noqa: E501
        :type: str
        """

        self._created = created

    @property
    def currency(self):
        """Gets the currency of this DisputeResponsePaymentData.  # noqa: E501

        Payment currency  # noqa: E501

        :return: The currency of this DisputeResponsePaymentData.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this DisputeResponsePaymentData.

        Payment currency  # noqa: E501

        :param currency: The currency of this DisputeResponsePaymentData.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def id(self):
        """Gets the id of this DisputeResponsePaymentData.  # noqa: E501

        Unlimint's payment id  # noqa: E501

        :return: The id of this DisputeResponsePaymentData.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DisputeResponsePaymentData.

        Unlimint's payment id  # noqa: E501

        :param id: The id of this DisputeResponsePaymentData.  # noqa: E501
        :type: str
        """

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(DisputeResponsePaymentData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DisputeResponsePaymentData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ThreeDSecureResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "card_enrollment": "str",
        "cardholder_info": "str",
        "cavv": "str",
        "cavv_algorithm": "str",
        "challenge_cancel": "str",
        "ds_transaction_id": "str",
        "eci": "str",
        "pa_res": "str",
        "protocol_version": "str",
        "status": "str",
        "status_reason": "str",
        "three_d_secure2_passed": "bool",
        "three_d_secure_flow": "str",
        "xid": "str",
    }

    attribute_map = {
        "card_enrollment": "card_enrollment",
        "cardholder_info": "cardholder_info",
        "cavv": "cavv",
        "cavv_algorithm": "cavv_algorithm",
        "challenge_cancel": "challenge_cancel",
        "ds_transaction_id": "ds_transaction_id",
        "eci": "eci",
        "pa_res": "pa_res",
        "protocol_version": "protocol_version",
        "status": "status",
        "status_reason": "status_reason",
        "three_d_secure2_passed": "three_d_secure2_passed",
        "three_d_secure_flow": "three_d_secure_flow",
        "xid": "xid",
    }

    def __init__(
        self,
        card_enrollment=None,
        cardholder_info=None,
        cavv=None,
        cavv_algorithm=None,
        challenge_cancel=None,
        ds_transaction_id=None,
        eci=None,
        pa_res=None,
        protocol_version=None,
        status=None,
        status_reason=None,
        three_d_secure2_passed=None,
        three_d_secure_flow=None,
        xid=None,
    ):  # noqa: E501
        """ThreeDSecureResponse - a model defined in Swagger"""  # noqa: E501

        self._card_enrollment = None
        self._cardholder_info = None
        self._cavv = None
        self._cavv_algorithm = None
        self._challenge_cancel = None
        self._ds_transaction_id = None
        self._eci = None
        self._pa_res = None
        self._protocol_version = None
        self._status = None
        self._status_reason = None
        self._three_d_secure2_passed = None
        self._three_d_secure_flow = None
        self._xid = None
        self.discriminator = None

        if card_enrollment is not None:
            self.card_enrollment = card_enrollment
        if cardholder_info is not None:
            self.cardholder_info = cardholder_info
        if cavv is not None:
            self.cavv = cavv
        if cavv_algorithm is not None:
            self.cavv_algorithm = cavv_algorithm
        if challenge_cancel is not None:
            self.challenge_cancel = challenge_cancel
        if ds_transaction_id is not None:
            self.ds_transaction_id = ds_transaction_id
        if eci is not None:
            self.eci = eci
        if pa_res is not None:
            self.pa_res = pa_res
        if protocol_version is not None:
            self.protocol_version = protocol_version
        if status is not None:
            self.status = status
        if status_reason is not None:
            self.status_reason = status_reason
        if three_d_secure2_passed is not None:
            self.three_d_secure2_passed = three_d_secure2_passed
        if three_d_secure_flow is not None:
            self.three_d_secure_flow = three_d_secure_flow
        if xid is not None:
            self.xid = xid

    @property
    def card_enrollment(self):
        """Gets the card_enrollment of this ThreeDSecureResponse.  # noqa: E501

        Card enrollment in 3DS flow, possible values are: S - 3D Secure Skipped, N - 3D Secure not enrolled, Y - 3D Secure enrolled  # noqa: E501

        :return: The card_enrollment of this ThreeDSecureResponse.  # noqa: E501
        :rtype: str
        """
        return self._card_enrollment

    @card_enrollment.setter
    def card_enrollment(self, card_enrollment):
        """Sets the card_enrollment of this ThreeDSecureResponse.

        Card enrollment in 3DS flow, possible values are: S - 3D Secure Skipped, N - 3D Secure not enrolled, Y - 3D Secure enrolled  # noqa: E501

        :param card_enrollment: The card_enrollment of this ThreeDSecureResponse.  # noqa: E501
        :type: str
        """

        self._card_enrollment = card_enrollment

    @property
    def cardholder_info(self):
        """Gets the cardholder_info of this ThreeDSecureResponse.  # noqa: E501

        Text provided by the ACS/Issuer to Cardholder during a Frictionless transaction  by the ACS.  # noqa: E501

        :return: The cardholder_info of this ThreeDSecureResponse.  # noqa: E501
        :rtype: str
        """
        return self._cardholder_info

    @cardholder_info.setter
    def cardholder_info(self, cardholder_info):
        """Sets the cardholder_info of this ThreeDSecureResponse.

        Text provided by the ACS/Issuer to Cardholder during a Frictionless transaction  by the ACS.  # noqa: E501

        :param cardholder_info: The cardholder_info of this ThreeDSecureResponse.  # noqa: E501
        :type: str
        """

        self._cardholder_info = cardholder_info

    @property
    def cavv(self):
        """Gets the cavv of this ThreeDSecureResponse.  # noqa: E501

        Cardholder authentication verification value  # noqa: E501

        :return: The cavv of this ThreeDSecureResponse.  # noqa: E501
        :rtype: str
        """
        return self._cavv

    @cavv.setter
    def cavv(self, cavv):
        """Sets the cavv of this ThreeDSecureResponse.

        Cardholder authentication verification value  # noqa: E501

        :param cavv: The cavv of this ThreeDSecureResponse.  # noqa: E501
        :type: str
        """

        self._cavv = cavv

    @property
    def cavv_algorithm(self):
        """Gets the cavv_algorithm of this ThreeDSecureResponse.  # noqa: E501

        CAVV algorithm  # noqa: E501

        :return: The cavv_algorithm of this ThreeDSecureResponse.  # noqa: E501
        :rtype: str
        """
        return self._cavv_algorithm

    @cavv_algorithm.setter
    def cavv_algorithm(self, cavv_algorithm):
        """Sets the cavv_algorithm of this ThreeDSecureResponse.

        CAVV algorithm  # noqa: E501

        :param cavv_algorithm: The cavv_algorithm of this ThreeDSecureResponse.  # noqa: E501
        :type: str
        """

        self._cavv_algorithm = cavv_algorithm

    @property
    def challenge_cancel(self):
        """Gets the challenge_cancel of this ThreeDSecureResponse.  # noqa: E501

        Indicator informing that the authentication has been cancelled  # noqa: E501

        :return: The challenge_cancel of this ThreeDSecureResponse.  # noqa: E501
        :rtype: str
        """
        return self._challenge_cancel

    @challenge_cancel.setter
    def challenge_cancel(self, challenge_cancel):
        """Sets the challenge_cancel of this ThreeDSecureResponse.

        Indicator informing that the authentication has been cancelled  # noqa: E501

        :param challenge_cancel: The challenge_cancel of this ThreeDSecureResponse.  # noqa: E501
        :type: str
        """

        self._challenge_cancel = challenge_cancel

    @property
    def ds_transaction_id(self):
        """Gets the ds_transaction_id of this ThreeDSecureResponse.  # noqa: E501

        Transaction Id  # noqa: E501

        :return: The ds_transaction_id of this ThreeDSecureResponse.  # noqa: E501
        :rtype: str
        """
        return self._ds_transaction_id

    @ds_transaction_id.setter
    def ds_transaction_id(self, ds_transaction_id):
        """Sets the ds_transaction_id of this ThreeDSecureResponse.

        Transaction Id  # noqa: E501

        :param ds_transaction_id: The ds_transaction_id of this ThreeDSecureResponse.  # noqa: E501
        :type: str
        """

        self._ds_transaction_id = ds_transaction_id

    @property
    def eci(self):
        """Gets the eci of this ThreeDSecureResponse.  # noqa: E501

        The electronic commerce indicator  # noqa: E501

        :return: The eci of this ThreeDSecureResponse.  # noqa: E501
        :rtype: str
        """
        return self._eci

    @eci.setter
    def eci(self, eci):
        """Sets the eci of this ThreeDSecureResponse.

        The electronic commerce indicator  # noqa: E501

        :param eci: The eci of this ThreeDSecureResponse.  # noqa: E501
        :type: str
        """

        self._eci = eci

    @property
    def pa_res(self):
        """Gets the pa_res of this ThreeDSecureResponse.  # noqa: E501

        PaRes bank authentication result  # noqa: E501

        :return: The pa_res of this ThreeDSecureResponse.  # noqa: E501
        :rtype: str
        """
        return self._pa_res

    @pa_res.setter
    def pa_res(self, pa_res):
        """Sets the pa_res of this ThreeDSecureResponse.

        PaRes bank authentication result  # noqa: E501

        :param pa_res: The pa_res of this ThreeDSecureResponse.  # noqa: E501
        :type: str
        """

        self._pa_res = pa_res

    @property
    def protocol_version(self):
        """Gets the protocol_version of this ThreeDSecureResponse.  # noqa: E501

        Protocol version identifier  # noqa: E501

        :return: The protocol_version of this ThreeDSecureResponse.  # noqa: E501
        :rtype: str
        """
        return self._protocol_version

    @protocol_version.setter
    def protocol_version(self, protocol_version):
        """Sets the protocol_version of this ThreeDSecureResponse.

        Protocol version identifier  # noqa: E501

        :param protocol_version: The protocol_version of this ThreeDSecureResponse.  # noqa: E501
        :type: str
        """

        self._protocol_version = protocol_version

    @property
    def status(self):
        """Gets the status of this ThreeDSecureResponse.  # noqa: E501

        3DS status (from PaRes for 3Ds 1.0, ARes message for 3Ds 2.0) (possible values Y,A,U,N)  # noqa: E501

        :return: The status of this ThreeDSecureResponse.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ThreeDSecureResponse.

        3DS status (from PaRes for 3Ds 1.0, ARes message for 3Ds 2.0) (possible values Y,A,U,N)  # noqa: E501

        :param status: The status of this ThreeDSecureResponse.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def status_reason(self):
        """Gets the status_reason of this ThreeDSecureResponse.  # noqa: E501

        Provides information on why the Status field has the specified value  # noqa: E501

        :return: The status_reason of this ThreeDSecureResponse.  # noqa: E501
        :rtype: str
        """
        return self._status_reason

    @status_reason.setter
    def status_reason(self, status_reason):
        """Sets the status_reason of this ThreeDSecureResponse.

        Provides information on why the Status field has the specified value  # noqa: E501

        :param status_reason: The status_reason of this ThreeDSecureResponse.  # noqa: E501
        :type: str
        """

        self._status_reason = status_reason

    @property
    def three_d_secure2_passed(self):
        """Gets the three_d_secure2_passed of this ThreeDSecureResponse.  # noqa: E501

        Sign of trying to pass 3ds2  # noqa: E501

        :return: The three_d_secure2_passed of this ThreeDSecureResponse.  # noqa: E501
        :rtype: bool
        """
        return self._three_d_secure2_passed

    @three_d_secure2_passed.setter
    def three_d_secure2_passed(self, three_d_secure2_passed):
        """Sets the three_d_secure2_passed of this ThreeDSecureResponse.

        Sign of trying to pass 3ds2  # noqa: E501

        :param three_d_secure2_passed: The three_d_secure2_passed of this ThreeDSecureResponse.  # noqa: E501
        :type: bool
        """

        self._three_d_secure2_passed = three_d_secure2_passed

    @property
    def three_d_secure_flow(self):
        """Gets the three_d_secure_flow of this ThreeDSecureResponse.  # noqa: E501

        Possible values: 3DS1 - 3DS 1.0 flow, 3DS2C - 3DS 2.0 challenge flow, 3DS2F - 3DS 2.0 frictionless flow  # noqa: E501

        :return: The three_d_secure_flow of this ThreeDSecureResponse.  # noqa: E501
        :rtype: str
        """
        return self._three_d_secure_flow

    @three_d_secure_flow.setter
    def three_d_secure_flow(self, three_d_secure_flow):
        """Sets the three_d_secure_flow of this ThreeDSecureResponse.

        Possible values: 3DS1 - 3DS 1.0 flow, 3DS2C - 3DS 2.0 challenge flow, 3DS2F - 3DS 2.0 frictionless flow  # noqa: E501

        :param three_d_secure_flow: The three_d_secure_flow of this ThreeDSecureResponse.  # noqa: E501
        :type: str
        """

        self._three_d_secure_flow = three_d_secure_flow

    @property
    def xid(self):
        """Gets the xid of this ThreeDSecureResponse.  # noqa: E501

        Transaction Id in PaRes  # noqa: E501

        :return: The xid of this ThreeDSecureResponse.  # noqa: E501
        :rtype: str
        """
        return self._xid

    @xid.setter
    def xid(self, xid):
        """Sets the xid of this ThreeDSecureResponse.

        Transaction Id in PaRes  # noqa: E501

        :param xid: The xid of this ThreeDSecureResponse.  # noqa: E501
        :type: str
        """

        self._xid = xid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(ThreeDSecureResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ThreeDSecureResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.three_d_secure_response import (
    ThreeDSecureResponse,
)  # noqa: F401,E501


class AuthenticationData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "amount": "float",
        "created": "str",
        "currency": "str",
        "decline_code": "str",
        "decline_reason": "str",
        "id": "str",
        "status": "str",
        "three_d_secure": "ThreeDSecureResponse",
        "trans_type": "str",
        "type": "str",
    }

    attribute_map = {
        "amount": "amount",
        "created": "created",
        "currency": "currency",
        "decline_code": "decline_code",
        "decline_reason": "decline_reason",
        "id": "id",
        "status": "status",
        "three_d_secure": "three_d_secure",
        "trans_type": "trans_type",
        "type": "type",
    }

    def __init__(
        self,
        amount=None,
        created=None,
        currency=None,
        decline_code=None,
        decline_reason=None,
        id=None,
        status=None,
        three_d_secure=None,
        trans_type=None,
        type=None,
    ):  # noqa: E501
        """AuthenticationData - a model defined in Swagger"""  # noqa: E501

        self._amount = None
        self._created = None
        self._currency = None
        self._decline_code = None
        self._decline_reason = None
        self._id = None
        self._status = None
        self._three_d_secure = None
        self._trans_type = None
        self._type = None
        self.discriminator = None

        if amount is not None:
            self.amount = amount
        if created is not None:
            self.created = created
        if currency is not None:
            self.currency = currency
        if decline_code is not None:
            self.decline_code = decline_code
        if decline_reason is not None:
            self.decline_reason = decline_reason
        if id is not None:
            self.id = id
        if status is not None:
            self.status = status
        if three_d_secure is not None:
            self.three_d_secure = three_d_secure
        if trans_type is not None:
            self.trans_type = trans_type
        if type is not None:
            self.type = type

    @property
    def amount(self):
        """Gets the amount of this AuthenticationData.  # noqa: E501

        Payment amount  # noqa: E501

        :return: The amount of this AuthenticationData.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this AuthenticationData.

        Payment amount  # noqa: E501

        :param amount: The amount of this AuthenticationData.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def created(self):
        """Gets the created of this AuthenticationData.  # noqa: E501

        Time when this payment started in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format (yyyy-MM-dd'T'HH:mm:ss'Z')  # noqa: E501

        :return: The created of this AuthenticationData.  # noqa: E501
        :rtype: str
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this AuthenticationData.

        Time when this payment started in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format (yyyy-MM-dd'T'HH:mm:ss'Z')  # noqa: E501

        :param created: The created of this AuthenticationData.  # noqa: E501
        :type: str
        """

        self._created = created

    @property
    def currency(self):
        """Gets the currency of this AuthenticationData.  # noqa: E501

        Payment currency code ([ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) code)  # noqa: E501

        :return: The currency of this AuthenticationData.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this AuthenticationData.

        Payment currency code ([ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) code)  # noqa: E501

        :param currency: The currency of this AuthenticationData.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def decline_code(self):
        """Gets the decline_code of this AuthenticationData.  # noqa: E501

        Decline code (only in decline case)  # noqa: E501

        :return: The decline_code of this AuthenticationData.  # noqa: E501
        :rtype: str
        """
        return self._decline_code

    @decline_code.setter
    def decline_code(self, decline_code):
        """Sets the decline_code of this AuthenticationData.

        Decline code (only in decline case)  # noqa: E501

        :param decline_code: The decline_code of this AuthenticationData.  # noqa: E501
        :type: str
        """

        self._decline_code = decline_code

    @property
    def decline_reason(self):
        """Gets the decline_reason of this AuthenticationData.  # noqa: E501

        Bank's message about transaction decline reason (only in decline case)  # noqa: E501

        :return: The decline_reason of this AuthenticationData.  # noqa: E501
        :rtype: str
        """
        return self._decline_reason

    @decline_reason.setter
    def decline_reason(self, decline_reason):
        """Sets the decline_reason of this AuthenticationData.

        Bank's message about transaction decline reason (only in decline case)  # noqa: E501

        :param decline_reason: The decline_reason of this AuthenticationData.  # noqa: E501
        :type: str
        """

        self._decline_reason = decline_reason

    @property
    def id(self):
        """Gets the id of this AuthenticationData.  # noqa: E501

        Unlimint's payment id  # noqa: E501

        :return: The id of this AuthenticationData.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AuthenticationData.

        Unlimint's payment id  # noqa: E501

        :param id: The id of this AuthenticationData.  # noqa: E501
        :type: str
        """

        self._id = id

    class Status(object):
        NEW = "NEW"
        IN_PROGRESS = "IN_PROGRESS"
        DECLINED = "DECLINED"
        AUTHORIZED = "AUTHORIZED"
        COMPLETED = "COMPLETED"
        CANCELLED = "CANCELLED"
        REFUNDED = "REFUNDED"
        VOIDED = "VOIDED"
        TERMINATED = "TERMINATED"
        CHARGED_BACK = "CHARGED_BACK"
        CHARGEBACK_RESOLVED = "CHARGEBACK_RESOLVED"

    @property
    def status(self):
        """Gets the status of this AuthenticationData.  # noqa: E501

        Current payment status  # noqa: E501

        :return: The status of this AuthenticationData.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this AuthenticationData.

        Current payment status  # noqa: E501

        :param status: The status of this AuthenticationData.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "NEW",
            "IN_PROGRESS",
            "DECLINED",
            "AUTHORIZED",
            "COMPLETED",
            "CANCELLED",
            "REFUNDED",
            "VOIDED",
            "TERMINATED",
            "CHARGED_BACK",
            "CHARGEBACK_RESOLVED",
        ]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                    status, allowed_values
                )
            )

        self._status = status

    @property
    def three_d_secure(self):
        """Gets the three_d_secure of this AuthenticationData.  # noqa: E501

        3D Secure results data  # noqa: E501

        :return: The three_d_secure of this AuthenticationData.  # noqa: E501
        :rtype: ThreeDSecureResponse
        """
        return self._three_d_secure

    @three_d_secure.setter
    def three_d_secure(self, three_d_secure):
        """Sets the three_d_secure of this AuthenticationData.

        3D Secure results data  # noqa: E501

        :param three_d_secure: The three_d_secure of this AuthenticationData.  # noqa: E501
        :type: ThreeDSecureResponse
        """

        self._three_d_secure = three_d_secure

    class TransType(object):
        _01 = "01"
        _03 = "03"
        _10 = "10"
        _11 = "11"
        _28 = "28"

    @property
    def trans_type(self):
        """Gets the trans_type of this AuthenticationData.  # noqa: E501


        :return: The trans_type of this AuthenticationData.  # noqa: E501
        :rtype: str
        """
        return self._trans_type

    @trans_type.setter
    def trans_type(self, trans_type):
        """Sets the trans_type of this AuthenticationData.


        :param trans_type: The trans_type of this AuthenticationData.  # noqa: E501
        :type: str
        """
        allowed_values = ["01", "03", "10", "11", "28"]  # noqa: E501
        if trans_type not in allowed_values:
            raise ValueError(
                "Invalid value for `trans_type` ({0}), must be one of {1}".format(  # noqa: E501
                    trans_type, allowed_values
                )
            )

        self._trans_type = trans_type

    @property
    def type(self):
        """Gets the type of this AuthenticationData.  # noqa: E501


        :return: The type of this AuthenticationData.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this AuthenticationData.


        :param type: The type of this AuthenticationData.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(AuthenticationData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuthenticationData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DisputeResponseDisputeData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "due_time": "str",
        "group_id": "str",
        "reason_code": "str",
        "reason_description": "str",
        "reg_time": "str",
        "result_time": "str",
        "stage": "str",
        "status": "str",
        "type": "str",
    }

    attribute_map = {
        "due_time": "due_time",
        "group_id": "group_id",
        "reason_code": "reason_code",
        "reason_description": "reason_description",
        "reg_time": "reg_time",
        "result_time": "result_time",
        "stage": "stage",
        "status": "status",
        "type": "type",
    }

    def __init__(
        self,
        due_time=None,
        group_id=None,
        reason_code=None,
        reason_description=None,
        reg_time=None,
        result_time=None,
        stage=None,
        status=None,
        type=None,
    ):  # noqa: E501
        """DisputeResponseDisputeData - a model defined in Swagger"""  # noqa: E501

        self._due_time = None
        self._group_id = None
        self._reason_code = None
        self._reason_description = None
        self._reg_time = None
        self._result_time = None
        self._stage = None
        self._status = None
        self._type = None
        self.discriminator = None

        if due_time is not None:
            self.due_time = due_time
        if group_id is not None:
            self.group_id = group_id
        if reason_code is not None:
            self.reason_code = reason_code
        if reason_description is not None:
            self.reason_description = reason_description
        if reg_time is not None:
            self.reg_time = reg_time
        if result_time is not None:
            self.result_time = result_time
        if stage is not None:
            self.stage = stage
        if status is not None:
            self.status = status
        if type is not None:
            self.type = type

    @property
    def due_time(self):
        """Gets the due_time of this DisputeResponseDisputeData.  # noqa: E501

        Due date and time in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format for making decision or action over chargeback/retrieval request, i.e accepting, disputing or providing evidence documents (format - yyyy-MM-dd'T'HH:mm:ss'Z')  # noqa: E501

        :return: The due_time of this DisputeResponseDisputeData.  # noqa: E501
        :rtype: str
        """
        return self._due_time

    @due_time.setter
    def due_time(self, due_time):
        """Sets the due_time of this DisputeResponseDisputeData.

        Due date and time in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format for making decision or action over chargeback/retrieval request, i.e accepting, disputing or providing evidence documents (format - yyyy-MM-dd'T'HH:mm:ss'Z')  # noqa: E501

        :param due_time: The due_time of this DisputeResponseDisputeData.  # noqa: E501
        :type: str
        """

        self._due_time = due_time

    @property
    def group_id(self):
        """Gets the group_id of this DisputeResponseDisputeData.  # noqa: E501

        Dispute group ID in Disputes Resolution Center that includes returned dispute entity  # noqa: E501

        :return: The group_id of this DisputeResponseDisputeData.  # noqa: E501
        :rtype: str
        """
        return self._group_id

    @group_id.setter
    def group_id(self, group_id):
        """Sets the group_id of this DisputeResponseDisputeData.

        Dispute group ID in Disputes Resolution Center that includes returned dispute entity  # noqa: E501

        :param group_id: The group_id of this DisputeResponseDisputeData.  # noqa: E501
        :type: str
        """

        self._group_id = group_id

    @property
    def reason_code(self):
        """Gets the reason_code of this DisputeResponseDisputeData.  # noqa: E501

        Dispute's reason code  # noqa: E501

        :return: The reason_code of this DisputeResponseDisputeData.  # noqa: E501
        :rtype: str
        """
        return self._reason_code

    @reason_code.setter
    def reason_code(self, reason_code):
        """Sets the reason_code of this DisputeResponseDisputeData.

        Dispute's reason code  # noqa: E501

        :param reason_code: The reason_code of this DisputeResponseDisputeData.  # noqa: E501
        :type: str
        """

        self._reason_code = reason_code

    @property
    def reason_description(self):
        """Gets the reason_description of this DisputeResponseDisputeData.  # noqa: E501

        Dispute's reason code description  # noqa: E501

        :return: The reason_description of this DisputeResponseDisputeData.  # noqa: E501
        :rtype: str
        """
        return self._reason_description

    @reason_description.setter
    def reason_description(self, reason_description):
        """Sets the reason_description of this DisputeResponseDisputeData.

        Dispute's reason code description  # noqa: E501

        :param reason_description: The reason_description of this DisputeResponseDisputeData.  # noqa: E501
        :type: str
        """

        self._reason_description = reason_description

    @property
    def reg_time(self):
        """Gets the reg_time of this DisputeResponseDisputeData.  # noqa: E501

        Dispute registration date in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format (format - yyyy-MM-dd'T'HH:mm:ss'Z')  # noqa: E501

        :return: The reg_time of this DisputeResponseDisputeData.  # noqa: E501
        :rtype: str
        """
        return self._reg_time

    @reg_time.setter
    def reg_time(self, reg_time):
        """Sets the reg_time of this DisputeResponseDisputeData.

        Dispute registration date in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format (format - yyyy-MM-dd'T'HH:mm:ss'Z')  # noqa: E501

        :param reg_time: The reg_time of this DisputeResponseDisputeData.  # noqa: E501
        :type: str
        """

        self._reg_time = reg_time

    @property
    def result_time(self):
        """Gets the result_time of this DisputeResponseDisputeData.  # noqa: E501

        Dispute's terminal (final) status date and time in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format (format - yyyy-MM-dd'T'HH:mm:ss'Z')  # noqa: E501

        :return: The result_time of this DisputeResponseDisputeData.  # noqa: E501
        :rtype: str
        """
        return self._result_time

    @result_time.setter
    def result_time(self, result_time):
        """Sets the result_time of this DisputeResponseDisputeData.

        Dispute's terminal (final) status date and time in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format (format - yyyy-MM-dd'T'HH:mm:ss'Z')  # noqa: E501

        :param result_time: The result_time of this DisputeResponseDisputeData.  # noqa: E501
        :type: str
        """

        self._result_time = result_time

    @property
    def stage(self):
        """Gets the stage of this DisputeResponseDisputeData.  # noqa: E501

        Chargeback/retrieval request's current stage  # noqa: E501

        :return: The stage of this DisputeResponseDisputeData.  # noqa: E501
        :rtype: str
        """
        return self._stage

    @stage.setter
    def stage(self, stage):
        """Sets the stage of this DisputeResponseDisputeData.

        Chargeback/retrieval request's current stage  # noqa: E501

        :param stage: The stage of this DisputeResponseDisputeData.  # noqa: E501
        :type: str
        """

        self._stage = stage

    @property
    def status(self):
        """Gets the status of this DisputeResponseDisputeData.  # noqa: E501

        Chargeback/retrieval request's current status  # noqa: E501

        :return: The status of this DisputeResponseDisputeData.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DisputeResponseDisputeData.

        Chargeback/retrieval request's current status  # noqa: E501

        :param status: The status of this DisputeResponseDisputeData.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def type(self):
        """Gets the type of this DisputeResponseDisputeData.  # noqa: E501

        Indicates dispute entity type: `CB` - for chargebacks `RR` - for retrieval requests `FR` - for fraud reports  # noqa: E501

        :return: The type of this DisputeResponseDisputeData.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this DisputeResponseDisputeData.

        Indicates dispute entity type: `CB` - for chargebacks `RR` - for retrieval requests `FR` - for fraud reports  # noqa: E501

        :param type: The type of this DisputeResponseDisputeData.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(DisputeResponseDisputeData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DisputeResponseDisputeData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.report import Report  # noqa: F401,E501


class ReportsResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "download_url": "str",
        "hash_sum": "str",
        "reports": "list[Report]",
        "sample_id": "str",
        "size": "int",
    }

    attribute_map = {
        "download_url": "downloadUrl",
        "hash_sum": "hashSum",
        "reports": "reports",
        "sample_id": "sampleId",
        "size": "size",
    }

    def __init__(
        self, download_url=None, hash_sum=None, reports=None, sample_id=None, size=None
    ):  # noqa: E501
        """ReportsResponse - a model defined in Swagger"""  # noqa: E501

        self._download_url = None
        self._hash_sum = None
        self._reports = None
        self._sample_id = None
        self._size = None
        self.discriminator = None

        if download_url is not None:
            self.download_url = download_url
        if hash_sum is not None:
            self.hash_sum = hash_sum
        if reports is not None:
            self.reports = reports
        if sample_id is not None:
            self.sample_id = sample_id
        if size is not None:
            self.size = size

    @property
    def download_url(self):
        """Gets the download_url of this ReportsResponse.  # noqa: E501


        :return: The download_url of this ReportsResponse.  # noqa: E501
        :rtype: str
        """
        return self._download_url

    @download_url.setter
    def download_url(self, download_url):
        """Sets the download_url of this ReportsResponse.


        :param download_url: The download_url of this ReportsResponse.  # noqa: E501
        :type: str
        """

        self._download_url = download_url

    @property
    def hash_sum(self):
        """Gets the hash_sum of this ReportsResponse.  # noqa: E501


        :return: The hash_sum of this ReportsResponse.  # noqa: E501
        :rtype: str
        """
        return self._hash_sum

    @hash_sum.setter
    def hash_sum(self, hash_sum):
        """Sets the hash_sum of this ReportsResponse.


        :param hash_sum: The hash_sum of this ReportsResponse.  # noqa: E501
        :type: str
        """

        self._hash_sum = hash_sum

    @property
    def reports(self):
        """Gets the reports of this ReportsResponse.  # noqa: E501


        :return: The reports of this ReportsResponse.  # noqa: E501
        :rtype: list[Report]
        """
        return self._reports

    @reports.setter
    def reports(self, reports):
        """Sets the reports of this ReportsResponse.


        :param reports: The reports of this ReportsResponse.  # noqa: E501
        :type: list[Report]
        """

        self._reports = reports

    @property
    def sample_id(self):
        """Gets the sample_id of this ReportsResponse.  # noqa: E501


        :return: The sample_id of this ReportsResponse.  # noqa: E501
        :rtype: str
        """
        return self._sample_id

    @sample_id.setter
    def sample_id(self, sample_id):
        """Sets the sample_id of this ReportsResponse.


        :param sample_id: The sample_id of this ReportsResponse.  # noqa: E501
        :type: str
        """

        self._sample_id = sample_id

    @property
    def size(self):
        """Gets the size of this ReportsResponse.  # noqa: E501


        :return: The size of this ReportsResponse.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this ReportsResponse.


        :param size: The size of this ReportsResponse.  # noqa: E501
        :type: int
        """

        self._size = size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(ReportsResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReportsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.reports_data import ReportsData  # noqa: F401,E501
from cardpay.model.request import Request  # noqa: F401,E501


class ReportsRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "callback_url": "str",
        "reports_data": "ReportsData",
        "request": "Request",
    }

    attribute_map = {
        "callback_url": "callback_url",
        "reports_data": "reports_data",
        "request": "request",
    }

    def __init__(
        self, callback_url=None, reports_data=None, request=None
    ):  # noqa: E501
        """ReportsRequest - a model defined in Swagger"""  # noqa: E501

        self._callback_url = None
        self._reports_data = None
        self._request = None
        self.discriminator = None

        if callback_url is not None:
            self.callback_url = callback_url
        self.reports_data = reports_data
        self.request = request

    @property
    def callback_url(self):
        """Gets the callback_url of this ReportsRequest.  # noqa: E501

        Url for sending resulted callback. If field is skipped then callback won't be sent  # noqa: E501

        :return: The callback_url of this ReportsRequest.  # noqa: E501
        :rtype: str
        """
        return self._callback_url

    @callback_url.setter
    def callback_url(self, callback_url):
        """Sets the callback_url of this ReportsRequest.

        Url for sending resulted callback. If field is skipped then callback won't be sent  # noqa: E501

        :param callback_url: The callback_url of this ReportsRequest.  # noqa: E501
        :type: str
        """
        if callback_url is not None and len(callback_url) > 512:
            raise ValueError(
                "Invalid value for `callback_url`, length must be less than or equal to `512`"
            )  # noqa: E501
        if callback_url is not None and len(callback_url) < 0:
            raise ValueError(
                "Invalid value for `callback_url`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._callback_url = callback_url

    @property
    def reports_data(self):
        """Gets the reports_data of this ReportsRequest.  # noqa: E501

        Contains data which describe requested report  # noqa: E501

        :return: The reports_data of this ReportsRequest.  # noqa: E501
        :rtype: ReportsData
        """
        return self._reports_data

    @reports_data.setter
    def reports_data(self, reports_data):
        """Sets the reports_data of this ReportsRequest.

        Contains data which describe requested report  # noqa: E501

        :param reports_data: The reports_data of this ReportsRequest.  # noqa: E501
        :type: ReportsData
        """
        if reports_data is None:
            raise ValueError(
                "Invalid value for `reports_data`, must not be `None`"
            )  # noqa: E501

        self._reports_data = reports_data

    @property
    def request(self):
        """Gets the request of this ReportsRequest.  # noqa: E501

        Request  # noqa: E501

        :return: The request of this ReportsRequest.  # noqa: E501
        :rtype: Request
        """
        return self._request

    @request.setter
    def request(self, request):
        """Sets the request of this ReportsRequest.

        Request  # noqa: E501

        :param request: The request of this ReportsRequest.  # noqa: E501
        :type: Request
        """
        if request is None:
            raise ValueError(
                "Invalid value for `request`, must not be `None`"
            )  # noqa: E501

        self._request = request

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(ReportsRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReportsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cardpay.api_client import ApiClient


class ReportsApiControllerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def g_et_reports(self, id, **kwargs):  # noqa: E501
        """Gets actual state of processing of requested settlement reports  # noqa: E501

        :param str id: id (required)
        :return: ReportsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.g_et_reports_with_http_info(id, **kwargs)  # noqa: E501
        return data

    def g_et_reports_with_http_info(self, id, **kwargs):  # noqa: E501
        """Gets actual state of processing of requested settlement reports  # noqa: E501

        :param str id: id (required)
        :return: ReportsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["id"]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method g_et_reports" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'id' is set
        if "id" not in params or params["id"] is None:
            raise ValueError(
                "Missing the required parameter `id` when calling `g_et_reports`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "id" in params:
            path_params["id"] = params["id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["*/*"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/reports/{id}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ReportsResponse",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def g_et_reports_content(self, file_id, **kwargs):  # noqa: E501
        """Download prepared file: single report by id or all reports collected into archive by sample id  # noqa: E501

        :param str file_id: file_id (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.g_et_reports_content_with_http_info(
            file_id, **kwargs
        )  # noqa: E501
        return data

    def g_et_reports_content_with_http_info(self, file_id, **kwargs):  # noqa: E501
        """Download prepared file: single report by id or all reports collected into archive by sample id  # noqa: E501

        :param str file_id: file_id (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["file_id"]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method g_et_reports_content" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'file_id' is set
        if "file_id" not in params or params["file_id"] is None:
            raise ValueError(
                "Missing the required parameter `file_id` when calling `g_et_reports_content`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if "file_id" in params:
            query_params.append(("file_id", params["file_id"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["*/*"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/reports/download",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="str",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def p_ost_reports(self, request, **kwargs):  # noqa: E501
        """Starts preparation of settlement reports for merchants  # noqa: E501

        :param ReportsRequest request: request (required)
        :return: ReportsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.p_ost_reports_with_http_info(request, **kwargs)  # noqa: E501
        return data

    def p_ost_reports_with_http_info(self, request, **kwargs):  # noqa: E501
        """Starts preparation of settlement reports for merchants  # noqa: E501

        :param ReportsRequest request: request (required)
        :return: ReportsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["request"]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method p_ost_reports" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'request' is set
        if "request" not in params or params["request"] is None:
            raise ValueError(
                "Missing the required parameter `request` when calling `p_ost_reports`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "request" in params:
            body_params = params["request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["*/*"]
        )  # noqa: E501
        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/reports",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ReportsResponse",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )
